import java.util.HashMap;

/**
 * @author Dave Reed
 */
public class StudentRecord implements Comparable<StudentRecord> {
    private HashMap<Integer, Quiz> quizzes;
    private String name;
    
    public StudentRecord(String name) {
        this.name = name;
        quizzes = new HashMap<Integer, Quiz>();
    }
    
    public void recordQuiz(int quizNum, int pointsEarned, int pointsPossible) {
        this.quizzes.put(quizNum, new Quiz(pointsEarned, pointsPossible));
    }
    
    public double quizAverage() {
        int totalPoints = 0;
        int totalPossible = 0;
        for (Integer i : this.quizzes.keySet()) {
            totalPoints += this.quizzes.get(i).getPoints();
            totalPossible += this.quizzes.get(i).getPossible();
        }
        
        if (totalPossible == 0) {
            return 0.0;
        }
        else {
            return 100.0*totalPoints/totalPossible;
        }
    }
    
    public String toString() {
        return this.name + " " + this.quizAverage();
    }
    
    public int compareTo(StudentRecord other) {
        double thisAvg = this.quizAverage();
        double otherAvg = other.quizAverage();
        if (thisAvg > otherAvg) {
            return -1;
        }
        else if (thisAvg < otherAvg) {
            return 1;
        }
        else {
            return this.name.compareTo(other.name);
        
        }
    }
}
